==> estateplat-common-1.2.4-20201106.071614-492-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlGjzwsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltQlGjzwsyq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltQlGjzwsyqBdc extends QltQlGjzwsyq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfgjzwlxdm;
    private String dfgjzwlxmc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlTransient
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlTransient
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlTransient
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFGJZWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxdm() {
        return dfgjzwlxdm;
    }

    public void setDfgjzwlxdm(String dfgjzwlxdm) {
        this.dfgjzwlxdm = dfgjzwlxdm;
    }
    @XmlTransient
    public String getDfgjzwlxmc() {
        return dfgjzwlxmc;
    }

    public void setDfgjzwlxmc(String dfgjzwlxmc) {
        this.dfgjzwlxmc = dfgjzwlxmc;
    }
}

==> estateplat-common-1.2.4-20201112.065422-500-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlGjzwsyqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltQlGjzwsyq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltQlGjzwsyqBdc extends QltQlGjzwsyq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfgjzwlxdm;
    private String dfgjzwlxmc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFGJZWLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxdm() {
        return dfgjzwlxdm;
    }

    public void setDfgjzwlxdm(String dfgjzwlxdm) {
        this.dfgjzwlxdm = dfgjzwlxdm;
    }
    @XmlAttribute(
            name = "DFGJZWLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgjzwlxmc() {
        return dfgjzwlxmc;
    }

    public void setDfgjzwlxmc(String dfgjzwlxmc) {
        this.dfgjzwlxmc = dfgjzwlxmc;
    }
}
